==> rbellogger-0.7.0-sources.jar: de/gematik/rbellogger/data/RbelListElement.java <==
/*
 * Copyright (c) 2021 gematik GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *    http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.rbellogger.data;

import de.gematik.rbellogger.converter.RbelConverter;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import lombok.Data;
import lombok.RequiredArgsConstructor;

@Data
@RequiredArgsConstructor
public class RbelListElement extends RbelElement {

    private final List<RbelElement> elementList;

    @Override
    public List<RbelElement> getChildNodes() {
        return elementList;
    }

    @Override
    public String getContent() {
        return elementList.toString();
    }

    @Override
    public boolean isNestedBoundary() {
        return false;
    }

    @Override
    public Map<String, RbelElement> getChildElements() {
        Map<String, RbelElement> result = new HashMap<>();
        int index = 0;
        for (RbelElement element : elementList) {
            result.put(String.valueOf(index++), element);
        }
        return result;
    }
}

==> rbellogger-0.8.1-sources.jar: de/gematik/rbellogger/data/RbelListElement.java <==
/*
 * Copyright (c) 2021 gematik GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an 'AS IS' BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.rbellogger.data;

import de.gematik.rbellogger.converter.RbelConverter;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;
import lombok.Data;
import lombok.RequiredArgsConstructor;

@Data
@RequiredArgsConstructor
public class RbelListElement extends RbelElement {

    private final List<RbelElement> elementList;

    @Override
    public List<RbelElement> getChildNodes() {
        return elementList;
    }

    @Override
    public String getContent() {
        return elementList.toString();
    }

    @Override
    public boolean isNestedBoundary() {
        return false;
    }

    @Override
    public Set<Entry<String, RbelElement>> getChildElements() {
        Map<String, RbelElement> result = new HashMap<>();
        int index = 0;
        for (RbelElement element : elementList) {
            result.put(String.valueOf(index++), element);
        }
        return result.entrySet();
    }
}
